@@ -46,12 +46,12 @@ def find_option(code, option_name):
 
 
 class CppKernel(Kernel):
-	implementation = 'CppKernel'
+	implementation = 'ipycpp'
 	implementation_version = '1.0'
 	language = 'cpp'
 	language_version = '0.1'
 	language_info = {
-		'name': 'Cpp files',
+		'name': 'cpp',
 		'mimetype': 'text/x-c',
 		'file_extension': '.cpp',
 	}
